@@ -1,5 +1,7 @@
 import unittest
-from config_guiosoft.validation_key import ValidationKey, ValidationKeyException
+
+from config_guiosoft.validation_key import (ValidationKey,
+                                            ValidationKeyException)
 
 
 class TestValidationKey(unittest.TestCase):
